@@ -15,6 +15,6 @@ try:
     from . import draw
     __all__ = ['Trajectories', 'draw']
 except ImportError:
-    log.warning('''Looks like matplotlib can't be imported, drawing won't be available ''')
+    # log.warning('''Looks like matplotlib can't be imported,'''
+    #             '''drawing won't be available ''')
     __all__ = ['Trajectories']
-
